@@ -1,5 +1,4 @@
 from django.db import models
-from django import forms
 from django.utils import simplejson as json
 from decimal import Decimal
 import datetime
@@ -30,6 +29,13 @@ class JSONField(models.TextField):
     def formfield(self, **kwargs):
         return super(JSONField, self).formfield(form_class=JSONFormField, **kwargs)
 
+    def get_default(self):
+        if self.has_default():
+            if callable(self.default):
+                return self.default()
+            return self.default
+        return super(JSONField, self).get_default()
+
     def to_python(self, value):
         if isinstance(value, basestring):
             if value == "":
@@ -38,19 +44,14 @@ class JSONField(models.TextField):
         # TODO: Look for date/time/datetime objects within the structure?
         return value
 
-    def get_db_prep_save(self, value, connection=None):
+    def get_db_prep_value(self, value, connection=None, prepared=None):
         if value is None:
             return None
-        return json.dumps(value, default=default)
+        return json.dumps(value, default=default, separators=(',', ':'))
 
     def value_to_string(self, obj):
         value = self._get_val_from_obj(obj)
-        # Currently just returning the actual value, since otherwise I
-        # get a string when I serialize this object, when I really want a
-        # data structure.
-        # return self.get_db_prep_value(value)
-        return value
-
+        return self.get_db_prep_value(value)
 
 try:
     from south.modelsinspector import add_introspection_rules
